@@ -44,6 +44,7 @@ from fedmsg_meta_fedora_infrastructure.tests.ftpsync import *
 from fedmsg_meta_fedora_infrastructure.tests.bz import *
 from fedmsg_meta_fedora_infrastructure.tests.elections import *
 from fedmsg_meta_fedora_infrastructure.tests.fmn import *
+from fedmsg_meta_fedora_infrastructure.tests.fedimg import *
 
 from fedmsg_meta_fedora_infrastructure.tests.base import Base
 
@@ -60,9 +61,8 @@ class TestFASUserCreateLegacy(Base):
     expected_subti = "New FAS account:  'ralph'  (created by 'ralph')"
     expected_icon = "https://admin.fedoraproject.org/accounts/static" + \
         "/theme/fas/images/account.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro"
     expected_usernames = set(['ralph'])
     expected_objects = set(['users/ralph'])
     msg = {
@@ -88,9 +88,8 @@ class TestFASUserCreate(Base):
     expected_subti = "New FAS account:  'ralph'  (created by 'ralph')"
     expected_icon = "https://admin.fedoraproject.org/accounts/static" + \
         "/theme/fas/images/account.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro"
     expected_usernames = set(['ralph'])
     expected_objects = set(['users/ralph'])
     msg = {
@@ -115,9 +114,8 @@ class TestFASEditProfile(Base):
         "FAS profile:  comments"
     expected_icon = "https://admin.fedoraproject.org/accounts/static" + \
         "/theme/fas/images/account.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro"
     expected_usernames = set(['ralph'])
     expected_objects = set(['users/ralph'])
     msg = {
@@ -141,9 +139,8 @@ class TestFASEditGroupLegacy(Base):
         "ambassadors FAS group:  display_name"
     expected_icon = "https://admin.fedoraproject.org/accounts/static" + \
         "/theme/fas/images/account.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro"
     expected_usernames = set(['ralph'])
     expected_objects = set(['groups/ambassadors'])
     msg = {
@@ -166,9 +163,8 @@ class TestFASEditGroup(Base):
         "ambassadors FAS group:  display_name"
     expected_icon = "https://admin.fedoraproject.org/accounts/static" + \
         "/theme/fas/images/account.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro"
     expected_usernames = set(['ralph'])
     expected_objects = set(['groups/ambassadors'])
     msg = {
@@ -189,9 +185,8 @@ class TestFASGroupCreate(Base):
     expected_subti = "ralph created new FAS group ambassadors"
     expected_icon = "https://admin.fedoraproject.org/accounts/static" + \
         "/theme/fas/images/account.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro"
     expected_usernames = set(['ralph'])
     expected_objects = set(['groups/ambassadors'])
     msg = {
@@ -212,9 +207,8 @@ class TestFASRoleUpdate(Base):
     expected_subti = "toshio changed ralph's role in the ambassadors group"
     expected_icon = "https://admin.fedoraproject.org/accounts/static" + \
         "/theme/fas/images/account.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "8128b4c81d09ada7f95ac9dbf888fbea?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "085a38b9cf600926924645b292f0b7121a98a5165e559e0ad1882cfe33c6b395?s=64&d=retro"
     expected_usernames = set(['ralph', 'toshio'])
     expected_objects = set(['users/ralph', 'groups/ambassadors'])
     msg = {
@@ -236,9 +230,8 @@ class TestFASGroupRemove(Base):
     expected_subti = "toshio removed ralph from the ambassadors group"
     expected_icon = "https://admin.fedoraproject.org/accounts/static" + \
         "/theme/fas/images/account.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "8128b4c81d09ada7f95ac9dbf888fbea?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "085a38b9cf600926924645b292f0b7121a98a5165e559e0ad1882cfe33c6b395?s=64&d=retro"
     expected_usernames = set(['ralph', 'toshio'])
     expected_objects = set(['users/ralph', 'groups/ambassadors'])
     msg = {
@@ -261,9 +254,8 @@ class TestFASGroupSponsor(Base):
         "in the ambassadors group"
     expected_icon = "https://admin.fedoraproject.org/accounts/static" + \
         "/theme/fas/images/account.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "8128b4c81d09ada7f95ac9dbf888fbea?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "085a38b9cf600926924645b292f0b7121a98a5165e559e0ad1882cfe33c6b395?s=64&d=retro"
     expected_usernames = set(['ralph', 'toshio'])
     expected_objects = set(['users/ralph', 'groups/ambassadors'])
     msg = {
@@ -286,9 +278,8 @@ class TestFASGroupApply(Base):
         "in the ambassadors group"
     expected_icon = "https://admin.fedoraproject.org/accounts/static" + \
         "/theme/fas/images/account.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro"
     expected_usernames = set(['ralph'])
     expected_objects = set(['users/ralph', 'groups/ambassadors'])
     msg = {
@@ -319,9 +310,9 @@ class LegacyTestBodhiUpdateComplete(Base):
         "fedmsg-0.2.7-2.el6"
     expected_icon = "https://admin.fedoraproject.org/updates" + \
         "/static/images/bodhi-icon-48.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c" + \
+        "?s=64&d=retro"
     expected_usernames = set(['ralph'])
     expected_packages = set(['fedmsg'])
     expected_objects = set(['packages/fedmsg'])
@@ -408,13 +399,19 @@ class TestBodhiRequestMultiplePackagesPerUpdate(Base):
     expected_subti = "lmacken submitted " + \
         "gnome-settings-daemon-3.6.1-1.fc18,control-center-3.6.1-1.fc18" + \
         " to testing"
+    expected_markup = (
+        "<a href='https://admin.fedoraproject.org/updates/user/lmacken'>"
+        "lmacken</a> submitted "
+        "<a href='https://admin.fedoraproject.org/updates/"
+        "gnome-settings-daemon-3.6.1-1.fc18,control-center-3.6.1-1.fc18'>"
+        "gnome-settings-daemon-3.6.1-1.fc18,control-center-3.6.1-1.fc18</a>"
+        " to testing")
     expected_link = "https://admin.fedoraproject.org/updates/" + \
         "gnome-settings-daemon-3.6.1-1.fc18,control-center-3.6.1-1.fc18"
     expected_icon = "https://admin.fedoraproject.org/updates" + \
         "/static/images/bodhi-icon-48.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "9d953fa825bd80dfa6e45660b03adc2d?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "0d574577afa8deac19df2673cdea9aef45549ff8fac798ddaba61541c69e185a?s=64&d=retro"
     expected_usernames = set(['hadess'])
     expected_packages = set(['gnome-settings-daemon', 'control-center'])
     expected_objects = set([
@@ -618,12 +615,16 @@ class TestBodhiRequestUnpush(Base):
     """
     expected_title = "bodhi.update.request.unpush"
     expected_subti = "lmacken unpushed foo"
+    expected_markup = (
+        "<a href='https://admin.fedoraproject.org/updates/user/lmacken'>"
+        "lmacken</a> unpushed "
+        "<a href='https://admin.fedoraproject.org/updates/"
+        "foo'>foo</a>")
     expected_link = "https://admin.fedoraproject.org/updates/foo"
     expected_icon = "https://admin.fedoraproject.org/updates" + \
         "/static/images/bodhi-icon-48.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "0c35a75019e58e54fb58202db20d2c24?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "203f6cb95b44b5d38aa21425b066dd522d3e19d8919cf4b339f29e0ea7f03e9b?s=64&d=retro"
     expected_usernames = set(['lmacken'])
     expected_packages = set(['foo'])
     expected_objects = set(['packages/foo'])
@@ -647,12 +648,16 @@ class TestBodhiRequestObsolete(Base):
     """
     expected_title = "bodhi.update.request.obsolete"
     expected_subti = "lmacken obsoleted foo"
+    expected_markup = (
+        "<a href='https://admin.fedoraproject.org/updates/user/lmacken'>"
+        "lmacken</a> obsoleted "
+        "<a href='https://admin.fedoraproject.org/updates/"
+        "foo'>foo</a>")
     expected_link = "https://admin.fedoraproject.org/updates/foo"
     expected_icon = "https://admin.fedoraproject.org/updates" + \
         "/static/images/bodhi-icon-48.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "0c35a75019e58e54fb58202db20d2c24?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "203f6cb95b44b5d38aa21425b066dd522d3e19d8919cf4b339f29e0ea7f03e9b?s=64&d=retro"
     expected_usernames = set(['lmacken'])
     expected_packages = set(['foo'])
     expected_objects = set(['packages/foo'])
@@ -676,12 +681,16 @@ class TestBodhiRequestStable(Base):
     """
     expected_title = "bodhi.update.request.stable"
     expected_subti = "lmacken submitted foo to stable"
+    expected_markup = (
+        "<a href='https://admin.fedoraproject.org/updates/user/lmacken'>"
+        "lmacken</a> submitted "
+        "<a href='https://admin.fedoraproject.org/updates/"
+        "foo'>foo</a> to stable")
     expected_link = "https://admin.fedoraproject.org/updates/foo"
     expected_icon = "https://admin.fedoraproject.org/updates" + \
         "/static/images/bodhi-icon-48.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "0c35a75019e58e54fb58202db20d2c24?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "203f6cb95b44b5d38aa21425b066dd522d3e19d8919cf4b339f29e0ea7f03e9b?s=64&d=retro"
     expected_usernames = set(['lmacken'])
     expected_packages = set(['foo'])
     expected_objects = set(['packages/foo'])
@@ -705,12 +714,16 @@ class TestBodhiRequestRevoke(Base):
     """
     expected_title = "bodhi.update.request.revoke"
     expected_subti = "lmacken revoked foo"
+    expected_markup = (
+        "<a href='https://admin.fedoraproject.org/updates/user/lmacken'>"
+        "lmacken</a> revoked "
+        "<a href='https://admin.fedoraproject.org/updates/"
+        "foo'>foo</a>")
     expected_link = "https://admin.fedoraproject.org/updates/foo"
     expected_icon = "https://admin.fedoraproject.org/updates" + \
         "/static/images/bodhi-icon-48.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "0c35a75019e58e54fb58202db20d2c24?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "203f6cb95b44b5d38aa21425b066dd522d3e19d8919cf4b339f29e0ea7f03e9b?s=64&d=retro"
     expected_usernames = set(['lmacken'])
     expected_packages = set(['foo'])
     expected_objects = set(['packages/foo'])
@@ -734,12 +747,16 @@ class TestBodhiRequestTesting(Base):
     """
     expected_title = "bodhi.update.request.testing"
     expected_subti = "lmacken submitted foo to testing"
+    expected_markup = (
+        "<a href='https://admin.fedoraproject.org/updates/user/lmacken'>"
+        "lmacken</a> submitted "
+        "<a href='https://admin.fedoraproject.org/updates/"
+        "foo'>foo</a> to testing")
     expected_link = "https://admin.fedoraproject.org/updates/foo"
     expected_icon = "https://admin.fedoraproject.org/updates" + \
         "/static/images/bodhi-icon-48.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "0c35a75019e58e54fb58202db20d2c24?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "203f6cb95b44b5d38aa21425b066dd522d3e19d8919cf4b339f29e0ea7f03e9b?s=64&d=retro"
     expected_usernames = set(['lmacken'])
     expected_packages = set(['foo'])
     expected_objects = set(['packages/foo'])
@@ -763,13 +780,17 @@ class TestBodhiComment(Base):
     """
     expected_title = "bodhi.update.comment"
     expected_subti = "ralph commented on bodhi update fedmsg-1.0-1 (karma: -1)"
+    expected_markup = (
+        "<a href='https://admin.fedoraproject.org/updates/user/ralph'>"
+        "ralph</a> commented on bodhi update "
+        "<a href='https://admin.fedoraproject.org/updates/"
+        "fedmsg-1.0-1'>fedmsg-1.0-1</a> (karma: -1)")
     expected_link = "https://admin.fedoraproject.org/updates/fedmsg-1.0-1"
     expected_icon = "https://admin.fedoraproject.org/updates" + \
         "/static/images/bodhi-icon-48.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
-    expected_usernames = set(['ralph'])
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro"
+    expected_usernames = set(['ralph', 'codeblock'])
     expected_packages = set(['fedmsg'])
     expected_objects = set(['packages/fedmsg'])
 
@@ -782,7 +803,8 @@ class TestBodhiComment(Base):
                 "update_title": "fedmsg-1.0-1",
                 "group": None,
                 "author": "ralph",
-                "text": "Can you believe how much testing we're doing?",
+                "text": "Can you believe how much testing we're doing?"
+                " /cc @codeblock.",
                 "karma": -1,
                 "anonymous": False,
                 "timestamp": 1344344050.0
@@ -798,11 +820,13 @@ class TestBodhiOverrideTagged(Base):
     """
     expected_title = "bodhi.buildroot_override.tag"
     expected_subti = "lmacken submitted a buildroot override for fedmsg-1.0-1"
+    expected_markup = (
+        "<a href='https://admin.fedoraproject.org/updates/user/lmacken'>"
+        "lmacken</a> submitted a buildroot override for fedmsg-1.0-1")
     expected_icon = "https://admin.fedoraproject.org/updates" + \
         "/static/images/bodhi-icon-48.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "0c35a75019e58e54fb58202db20d2c24?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "203f6cb95b44b5d38aa21425b066dd522d3e19d8919cf4b339f29e0ea7f03e9b?s=64&d=retro"
     expected_usernames = set(['lmacken'])
     expected_packages = set(['fedmsg'])
     expected_objects = set(['packages/fedmsg'])
@@ -827,11 +851,13 @@ class TestBodhiOverrideUntagged(Base):
     """
     expected_title = "bodhi.buildroot_override.untag"
     expected_subti = "lmacken expired a buildroot override for fedmsg-1.0-1"
+    expected_markup = (
+        "<a href='https://admin.fedoraproject.org/updates/user/lmacken'>"
+        "lmacken</a> expired a buildroot override for fedmsg-1.0-1")
     expected_icon = "https://admin.fedoraproject.org/updates" + \
         "/static/images/bodhi-icon-48.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "0c35a75019e58e54fb58202db20d2c24?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "203f6cb95b44b5d38aa21425b066dd522d3e19d8919cf4b339f29e0ea7f03e9b?s=64&d=retro"
     expected_usernames = set(['lmacken'])
     expected_packages = set(['fedmsg'])
     expected_objects = set(['packages/fedmsg'])
@@ -859,9 +885,8 @@ class TestSupybotStartMeetingNoName(Base):
     expected_title = "meetbot.meeting.start"
     expected_subti = 'ralph started a meeting in #channel'
     expected_icon = 'https://apps.fedoraproject.org/img/icons/meetbot.png'
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro"
     expected_usernames = set(['ralph'])
     expected_objects = set([
         'attendees/ralph',
@@ -1186,7 +1211,7 @@ class TestPkgdb2BrMassComplete(Base):
 class TestPkgdb2BrRunStart(Base):
     """ There is a script called ``pkgdb2branch`` that gets run by an SCM
     admin as part of the new package process.  Typically, when an `SCM Admin
-    Request <http://fedoraproject.org/wiki/Package_SCM_admin_requests>`_ is
+    Request <https://fedoraproject.org/wiki/Package_SCM_admin_requests>`_ is
     approved, the scm admin will add the new package or branch to the package
     database.  *After that*, the scm admin will run ``pkgdb2branch`` to create
     the branch in git on the file system.  Messages of **this** topic are
@@ -1209,7 +1234,7 @@ class TestPkgdb2BrRunStart(Base):
 class TestPkgdb2BrRunComplete(Base):
     """ There is a script called ``pkgdb2branch`` that gets run by an SCM
     admin as part of the new package process.  Typically, when an `SCM Admin
-    Request <http://fedoraproject.org/wiki/Package_SCM_admin_requests>`_ is
+    Request <https://fedoraproject.org/wiki/Package_SCM_admin_requests>`_ is
     approved, the scm admin will add the new package or branch to the package
     database.  *After that*, the scm admin will run ``pkgdb2branch`` to create
     the branch in git on the file system.  Messages of **this** topic are
@@ -1236,7 +1261,7 @@ class TestPkgdb2BrRunComplete(Base):
 class TestPkgdb2BrRunCompleteWithError(Base):
     """ There is a script called ``pkgdb2branch`` that gets run by an SCM
     admin as part of the new package process.  Typically, when an `SCM Admin
-    Request <http://fedoraproject.org/wiki/Package_SCM_admin_requests>`_ is
+    Request <https://fedoraproject.org/wiki/Package_SCM_admin_requests>`_ is
     approved, the scm admin will add the new package or branch to the package
     database.  *After that*, the scm admin will run ``pkgdb2branch`` to create
     the branch in git on the file system.  Messages of **this** topic are
@@ -1267,7 +1292,7 @@ class TestPkgdb2BrRunCompleteWithError(Base):
 class TestPkgdb2BrRunCompleteWithErrors(Base):
     """ There is a script called ``pkgdb2branch`` that gets run by an SCM
     admin as part of the new package process.  Typically, when an `SCM Admin
-    Request <http://fedoraproject.org/wiki/Package_SCM_admin_requests>`_ is
+    Request <https://fedoraproject.org/wiki/Package_SCM_admin_requests>`_ is
     approved, the scm admin will add the new package or branch to the package
     database.  *After that*, the scm admin will run ``pkgdb2branch`` to create
     the branch in git on the file system.  Messages of **this** topic are
@@ -1323,7 +1348,7 @@ class TestPkgdb2BrCreateLegacy(Base):
 class TestPkgdb2BrCreate(Base):
     """ There is a script called ``pkgdb2branch`` that gets run by an SCM
     admin as part of the new package process.  Typically, when an `SCM Admin
-    Request <http://fedoraproject.org/wiki/Package_SCM_admin_requests>`_ is
+    Request <https://fedoraproject.org/wiki/Package_SCM_admin_requests>`_ is
     approved, the scm admin will add the new package or branch to the package
     database.  *After that*, the scm admin will run ``pkgdb2branch`` to create
     the branch in git on the file system.  Messages of **this** topic are
@@ -1358,10 +1383,9 @@ class TestLookaside(Base):
     expected_title = "git.lookaside.new"
     expected_subti = 'jnovy uploaded pst-diffraction.doc.tar.xz for texlive'
     expected_icon = "https://apps.fedoraproject.org/img/icons/git-logo.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "5b938b3dcb12f46b98a1269cab255cbe?s=64&" + \
-        "d=http%3A%2F%2Ffedoraproject.org%2Fstatic%2F" + \
-        "images%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "e0e8e0c4d995109cdac8ae4eb5766a73cf09c7a8d2d8bac57f761e6223ca094b?s=64&" + \
+        "d=retro"
     expected_link = 'http://pkgs.fedoraproject.org/lookaside/pkgs/' + \
         'texlive/pst-diffraction.doc.tar.xz/' + \
         'dacad985394b3977f9dcf0c75f51a357/' + \
@@ -1389,10 +1413,9 @@ class TestLookasideLegacy(Base):
     expected_title = "git.lookaside.texlive.new"
     expected_subti = 'jnovy uploaded pst-diffraction.doc.tar.xz for texlive'
     expected_icon = "https://apps.fedoraproject.org/img/icons/git-logo.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "5b938b3dcb12f46b98a1269cab255cbe?s=64&" + \
-        "d=http%3A%2F%2Ffedoraproject.org%2Fstatic%2F" + \
-        "images%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "e0e8e0c4d995109cdac8ae4eb5766a73cf09c7a8d2d8bac57f761e6223ca094b?s=64&" + \
+        "d=retro"
     expected_link = 'http://pkgs.fedoraproject.org/lookaside/pkgs/' + \
         'texlive/pst-diffraction.doc.tar.xz/' + \
         'dacad985394b3977f9dcf0c75f51a357/' + \
@@ -1424,10 +1447,9 @@ class TestSCMSuperLegacy(Base):
         "valgrind.git/commit/" + \
         "?h=master&id=7a98f80d9b61ce167e4ef8129c81ed9284ecf4e1"
     expected_icon = "https://apps.fedoraproject.org/img/icons/git-logo.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
         "923419d315c8f23eface39852bf32a5f?s=64&" + \
-        "d=http%3A%2F%2Ffedoraproject.org%2Fstatic%2F" + \
-        "images%2Ffedora_infinity_64x64.png"
+        "d=retro"
     expected_usernames = set(['mjw'])
     expected_packages = set(['valgrind'])
     expected_objects = set(['valgrind/valgrind.spec'])
@@ -1476,10 +1498,9 @@ class TestSCMLegacy(Base):
         "valgrind.git/commit/" + \
         "?h=master&id=7a98f80d9b61ce167e4ef8129c81ed9284ecf4e1"
     expected_icon = "https://apps.fedoraproject.org/img/icons/git-logo.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
         "923419d315c8f23eface39852bf32a5f?s=64&" + \
-        "d=http%3A%2F%2Ffedoraproject.org%2Fstatic%2F" + \
-        "images%2Ffedora_infinity_64x64.png"
+        "d=retro"
     expected_usernames = set(['mjw'])
     expected_packages = set(['valgrind'])
     expected_objects = set(['valgrind/valgrind.spec'])
@@ -1530,10 +1551,9 @@ class TestSCM(Base):
         "valgrind.git/commit/" + \
         "?h=master&id=7a98f80d9b61ce167e4ef8129c81ed9284ecf4e1"
     expected_icon = "https://apps.fedoraproject.org/img/icons/git-logo.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
         "923419d315c8f23eface39852bf32a5f?s=64&" + \
-        "d=http%3A%2F%2Ffedoraproject.org%2Fstatic%2F" + \
-        "images%2Ffedora_infinity_64x64.png"
+        "d=retro"
     expected_usernames = set(['mjw'])
     expected_packages = set(['valgrind'])
     expected_objects = set(['valgrind/valgrind.spec'])
@@ -1584,10 +1604,9 @@ class TestSCMSingleLine(Base):
         "ember.git/commit/" + \
         "?h=master&id=aa2df80f3d8dd217c7cbfe2d3451190028f3fe14"
     expected_icon = "https://apps.fedoraproject.org/img/icons/git-logo.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
         "461761d9572bdc1d04925a1125a41797?s=64&" + \
-        "d=http%3A%2F%2Ffedoraproject.org%2Fstatic%2F" + \
-        "images%2Ffedora_infinity_64x64.png"
+        "d=retro"
     expected_usernames = set(['spot'])
     expected_packages = set(['ember'])
     expected_objects = set(['ember/ember-0.6.3-gcc47.patch'])
